=== renamed file 'bzrlib/changeset/old/apply_changeset.py' => 'bzrlib/changeset/apply_changeset.py'
--- bzrlib/changeset/old/apply_changeset.py	2005-11-19 04:22:51 +0000
+++ bzrlib/changeset/apply_changeset.py	2006-05-12 05:06:27 +0000
@@ -19,7 +19,7 @@
 from bzrlib.osutils import sha_string, split_lines
 
 
-def _install_info(branch, cset_info, cset_tree):
+def _install_info(repository, cset_info, cset_tree):
     """Make sure that there is a text entry for each 
     file in the changeset.
 
@@ -32,8 +32,8 @@
           as ghost revisions)
     """
 
-    if not branch.has_revision(cset_info.target):
-        branch.lock_write()
+    if not repository.has_revision(cset_info.target):
+        repository.lock_write()
         try:
             # install the inventory
             # TODO: Figure out how to handle ghosted revisions
@@ -41,35 +41,36 @@
             parent_invs = []
             rev = cset_info.real_revisions[-1]
             for p_id in rev.parent_ids:
-                if branch.has_revision(p_id):
+                if repository.has_revision(p_id):
                     present_parents.append(p_id)
-                    parent_invs.append(branch.get_inventory(revision))
+                    parent_invs.append(repository.get_inventory(revision))
 
             inv = cset_tree.inventory
             
             # Add the texts that are not already present
             for path, ie in inv.iter_entries():
-                w = branch.weave_store.get_weave_or_empty(ie.file_id,
-                        branch.get_transaction())
+                w = repository.weave_store.get_weave_or_empty(ie.file_id,
+                        repository.get_transaction())
                 if ie.revision not in w._name_map:
-                    branch.weave_store.add_text(ie.file_id, rev.revision_id,
-                        cset_tree.get_file(ie.file_id).readlines(),
-                        present_parents, branch.get_transaction())
+                    repository.weave_store.add_text(ie.file_id, 
+                                                    rev.revision_id,
+                    cset_tree.get_file(ie.file_id).readlines(),
+                    present_parents, repository.get_transaction())
 
             # Now add the inventory information
             txt = serializer_v5.write_inventory_to_string(inv)
             sha1 = sha_string(txt)
-            branch.control_weaves.add_text('inventory', 
+            repository.control_weaves.add_text('inventory', 
                 rev.revision_id, 
                 split_lines(txt), 
                 present_parents,
-                branch.get_transaction())
+                repository.get_transaction())
 
             # And finally, insert the revision
             rev_tmp = StringIO()
             serializer_v5.write_revision(rev, rev_tmp)
             rev_tmp.seek(0)
-            branch.revision_store.add(rev_tmp, rev.revision_id)
+            repository.revision_store.add(rev_tmp, rev.revision_id)
         finally:
             branch.unlock()
 
@@ -85,17 +86,17 @@
     if reverse:
         raise Exception('reverse not implemented yet')
 
-    cset = read_changeset.read_changeset(from_file, branch)
+    cset = read_changeset.read_changeset(from_file, branch.repository)
 
     return _apply_cset(branch, cset, reverse=reverse, auto_commit=auto_commit)
         
-def _apply_cset(branch, cset, reverse=False, auto_commit=False):
+def _apply_cset(tree, cset, reverse=False, auto_commit=False):
     """Apply an in-memory changeset to a given branch.
     """
 
     cset_info, cset_tree = cset
 
-    _install_info(branch, cset_info, cset_tree)
+    _install_info(tree.branch.repository, cset_info, cset_tree)
 
     # We could technically optimize more, by using the ChangesetTree
     # we already have in memory, but after installing revisions
@@ -107,12 +108,14 @@
     #   for the merge, the merge code should pick the best merge
     #   based on the ancestry of both trees.
     #
-    if branch.last_revision() is None:
+    if tree.last_revision() is None:
         base = None
     else:
-        base = common_ancestor(branch.last_revision(), cset_info.target, branch)
-    merge_inner(branch, branch.revision_tree(cset_info.target),
-                branch.revision_tree(base))
+        base = common_ancestor(tree.last_revision(), cset_info.target, 
+                               tree.branch.repository)
+    merge_inner(tree.branch, 
+                tree.branch.repository.revision_tree(cset_info.target),
+                tree.branch.repository.revision_tree(base), this_tree=tree)
 
     auto_committed = False
     
@@ -189,7 +192,7 @@
                 print '** Could not auto-commit.'
 
     if not auto_committed:
-        branch.add_pending_merge(cset_info.target)
+        tree.add_pending_merge(cset_info.target)
 
     return auto_committed
 

=== modified file 'bzrlib/tests/changeset/old_tests.py'
--- bzrlib/tests/changeset/old_tests.py	2006-05-12 04:21:59 +0000
+++ bzrlib/tests/changeset/old_tests.py	2006-05-12 05:06:27 +0000
@@ -21,6 +21,7 @@
 
 from bzrlib.diff import internal_diff
 from bzrlib.changeset.read_changeset import ChangesetTree
+from bzrlib.workingtree import WorkingTree
 
 class MockTree(object):
     def __init__(self):
@@ -316,7 +317,7 @@
             # since it computes the sha1 hash for the revision, which
             # only will match if everything is okay, but lets be
             # explicit about it
-            branch_rev = self.b1.get_revision(cset_rev.revision_id)
+            branch_rev = self.b1.repository.get_revision(cset_rev.revision_id)
             for a in ('inventory_sha1', 'revision_id', 'parent_ids'
                     , 'timestamp', 'timezone', 'message', 'committer'):
                 self.assertEqual(getattr(branch_rev, a), getattr(cset_rev, a))
@@ -330,7 +331,6 @@
     def get_checkout(self, rev_id, checkout_dir=None):
         """Get a new tree, with the specified revision in it.
         """
-        from bzrlib.clone import copy_branch
         from bzrlib.branch import Branch
         import tempfile
 
@@ -340,26 +340,27 @@
             import os
             if not os.path.exists(checkout_dir):
                 os.mkdir(checkout_dir)
-        copy_branch(self.b1, checkout_dir, None)
-        return Branch.open(checkout_dir)
+        self.tree1.bzrdir.clone(checkout_dir)
+        return WorkingTree.open(checkout_dir)
 
     def valid_apply_changeset(self, base_rev_id, cset,
             auto_commit=False, checkout_dir=None):
         """Get the base revision, apply the changes, and make
         sure everything matches the builtin branch.
         """
-        from apply_changeset import _apply_cset
+        from bzrlib.changeset.apply_changeset import _apply_cset
 
-        to_branch = self.get_checkout(base_rev_id, checkout_dir=checkout_dir)
-        auto_committed = _apply_cset(to_branch, cset, auto_commit=auto_commit)
+        to_tree = self.get_checkout(base_rev_id, checkout_dir=checkout_dir)
+        auto_committed = _apply_cset(to_tree, cset, auto_commit=auto_commit)
 
         info = cset[0]
+        repository = to_tree.branch.repository
         for rev in info.real_revisions:
-            self.assert_(rev.revision_id in to_branch.revision_store,
+            self.assert_(repository.has_revision(rev.revision_id),
                 'Missing revision {%s} after applying changeset' 
                 % rev.revision_id)
 
-        self.assert_(to_branch.has_revision(info.target))
+        self.assert_(to_tree.branch.repository.has_revision(info.target))
         # Do we also want to verify that all the texts have been added?
 
 
@@ -371,14 +372,14 @@
             # We might also check that all revisions are in the
             # history for some changeset applications which
             # merge multiple revisions.
-            self.assertEqual(to_branch.last_patch(), info.target)
+            self.assertEqual(to_tree.branch.last_patch(), info.target)
         else:
-            self.assert_(info.target in to_branch.pending_merges())
+            self.assert_(info.target in to_tree.pending_merges())
 
 
         rev = info.real_revisions[-1]
-        base_tree = self.b1.revision_tree(rev.revision_id)
-        to_tree = to_branch.revision_tree(rev.revision_id)
+        base_tree = self.b1.repository.revision_tree(rev.revision_id)
+        to_tree = to_tree.branch.repository.revision_tree(rev.revision_id)
         
         # TODO: make sure the target tree is identical to base tree
         #       we might also check the working tree.

